# AUTOGENERATED! DO NOT EDIT! File to edit: ../../nbs/08a_vision.data.ipynb.

# %% ../../nbs/08a_vision.data.ipynb 1
from __future__ import annotations

# %% auto 0
__all__ = []

# %% ../../nbs/08a_vision.data.ipynb 3
from fastai.vision.all import *

from .core import *
