# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/fastgs',
                'doc_host': 'https://restlessronin.github.io',
                'git_url': 'https://github.com/restlessronin/fastgs',
                'lib_path': 'fastgs'},
  'syms': { 'fastgs.geospatial.sentinel': { 'fastgs.geospatial.sentinel.BandInputs': ( 'geospatial.sentinel.html#bandinputs',
                                                                                       'fastgs/geospatial/sentinel.py'),
                                            'fastgs.geospatial.sentinel.BandInputs._get_bands': ( 'geospatial.sentinel.html#bandinputs._get_bands',
                                                                                                  'fastgs/geospatial/sentinel.py'),
                                            'fastgs.geospatial.sentinel.BandInputs._get_index': ( 'geospatial.sentinel.html#bandinputs._get_index',
                                                                                                  'fastgs/geospatial/sentinel.py'),
                                            'fastgs.geospatial.sentinel.BandInputs.from_ids': ( 'geospatial.sentinel.html#bandinputs.from_ids',
                                                                                                'fastgs/geospatial/sentinel.py'),
                                            'fastgs.geospatial.sentinel.BandInputs.get_bands_list': ( 'geospatial.sentinel.html#bandinputs.get_bands_list',
                                                                                                      'fastgs/geospatial/sentinel.py'),
                                            'fastgs.geospatial.sentinel.Sentinel2': ( 'geospatial.sentinel.html#sentinel2',
                                                                                      'fastgs/geospatial/sentinel.py'),
                                            'fastgs.geospatial.sentinel.Sentinel2.__init__': ( 'geospatial.sentinel.html#sentinel2.__init__',
                                                                                               'fastgs/geospatial/sentinel.py'),
                                            'fastgs.geospatial.sentinel.Sentinel2._load_tensor': ( 'geospatial.sentinel.html#sentinel2._load_tensor',
                                                                                                   'fastgs/geospatial/sentinel.py'),
                                            'fastgs.geospatial.sentinel.Sentinel2.get_brgtX': ( 'geospatial.sentinel.html#sentinel2.get_brgtx',
                                                                                                'fastgs/geospatial/sentinel.py'),
                                            'fastgs.geospatial.sentinel.Sentinel2.get_brgtX_list': ( 'geospatial.sentinel.html#sentinel2.get_brgtx_list',
                                                                                                     'fastgs/geospatial/sentinel.py'),
                                            'fastgs.geospatial.sentinel.Sentinel2.get_res_ids': ( 'geospatial.sentinel.html#sentinel2.get_res_ids',
                                                                                                  'fastgs/geospatial/sentinel.py'),
                                            'fastgs.geospatial.sentinel.Sentinel2.load_tensor': ( 'geospatial.sentinel.html#sentinel2.load_tensor',
                                                                                                  'fastgs/geospatial/sentinel.py')},
            'fastgs.vision.core': { 'fastgs.vision.core.TensorImageMS': ('vision.core.html#tensorimagems', 'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS._brighten': ( 'vision.core.html#tensorimagems._brighten',
                                                                                    'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS._get_grid': ( 'vision.core.html#tensorimagems._get_grid',
                                                                                    'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS._select_bands': ( 'vision.core.html#tensorimagems._select_bands',
                                                                                        'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS._show_animation': ( 'vision.core.html#tensorimagems._show_animation',
                                                                                          'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS._show_tiles': ( 'vision.core.html#tensorimagems._show_tiles',
                                                                                      'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS.num_images': ( 'vision.core.html#tensorimagems.num_images',
                                                                                     'fastgs/vision/core.py'),
                                    'fastgs.vision.core.TensorImageMS.show': ( 'vision.core.html#tensorimagems.show',
                                                                               'fastgs/vision/core.py'),
                                    'fastgs.vision.core.create_TensorImageMS': ( 'vision.core.html#create_tensorimagems',
                                                                                 'fastgs/vision/core.py')},
            'fastgs.vision.data': {},
            'fastgs.vision.io': { 'fastgs.vision.io.filter_masked': ('vision.io.html#filter_masked', 'fastgs/vision/io.py'),
                                  'fastgs.vision.io.read_chn_file_as_tensor': ( 'vision.io.html#read_chn_file_as_tensor',
                                                                                'fastgs/vision/io.py'),
                                  'fastgs.vision.io.read_multichan_files_as_tensor': ( 'vision.io.html#read_multichan_files_as_tensor',
                                                                                       'fastgs/vision/io.py')}}}